# Generated by Django 3.2.25 on 2024-03-04 09:15

from django.conf import settings
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('fsmedhro_core', '0003_auto_20201107_2321'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='fachschaftuser',
            options={'ordering': ['nickname'], 'verbose_name': 'Student:in', 'verbose_name_plural': 'Student:innen'},
        ),
        migrations.CreateModel(
            name='Kontaktdaten',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='erzeugt')),
                ('adresse', models.TextField()),
                ('telefonnummer', models.CharField(default='', help_text="Telefonnummer muss von folgendem Format sein: '+4938149444614'. Es sind bis zu 15 Ziffern erlaubt.", max_length=16, validators=[django.core.validators.RegexValidator(message="Telefonnummer muss von folgendem Format sein: '+4938149444614'. Es sind bis zu 15 Ziffern erlaubt.", regex='^\\+\\d{9,15}$')], verbose_name='Telefonnummer')),
                ('gecheckt_datum', models.DateTimeField(blank=True, null=True, verbose_name='überprüft am')),
                ('fachschaftuser', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='kontaktdaten', to='fsmedhro_core.fachschaftuser')),
                ('gecheckt_von', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL, verbose_name='überprüft von')),
            ],
            options={
                'verbose_name': 'Kontaktdaten',
                'verbose_name_plural': 'Kontaktdaten',
                'ordering': ['-created'],
            },
        ),
    ]
